@@ -11,6 +11,8 @@
 #include <ctime>
 #include <cerrno>
 
+#include <utility>
+#include <compare>
 #include <string>
 #include <string_view>
 #include <vector>
@@ -52,33 +54,30 @@
 
 #if defined(__unix__) || defined(__APPLE__)
 const GUI::gui_char pathSepString[] = "/";
-const GUI::gui_char pathSepChar = '/';
+constexpr GUI::gui_char pathSepChar = '/';
 const GUI::gui_char listSepString[] = ":";
 const GUI::gui_char configFileVisibilityString[] = ".";
 #endif
-#ifdef WIN32
+#ifdef _WIN32
 // Windows
 const GUI::gui_char pathSepString[] = GUI_TEXT("\\");
-const GUI::gui_char pathSepChar = '\\';
+constexpr GUI::gui_char pathSepChar = '\\';
 const GUI::gui_char listSepString[] = GUI_TEXT(";");
 const GUI::gui_char configFileVisibilityString[] = GUI_TEXT("");
 #endif
 
-const GUI::gui_char fileRead[] = GUI_TEXT("rb");
-const GUI::gui_char fileWrite[] = GUI_TEXT("wb");
-
 namespace {
-const GUI::gui_char currentDirectory[] = GUI_TEXT(".");
-const GUI::gui_char parentDirectory[] = GUI_TEXT("..");
+const GUI::gui_string_view currentDirectory = GUI_TEXT(".");
+const GUI::gui_string_view parentDirectory = GUI_TEXT("..");
 }
 
 FilePath::FilePath() noexcept = default;
 
 FilePath::FilePath(const GUI::gui_char *fileName_) : fileName(fileName_ ? fileName_ : GUI_TEXT("")) {}
 
-FilePath::FilePath(const GUI::gui_string_view fileName_) : fileName(fileName_) {}
+FilePath::FilePath(GUI::gui_string_view fileName_) : fileName(fileName_) {}
 
-FilePath::FilePath(const GUI::gui_string &fileName_) : fileName(fileName_) {}
+FilePath::FilePath(GUI::gui_string fileName_) noexcept : fileName(std::move(fileName_)) {}
 
 FilePath::FilePath(FilePath const &directory, FilePath const &name) {
 	Set(directory, name);
@@ -97,7 +96,7 @@ void FilePath::Set(FilePath const &directory, FilePath const &name) {
 		fileName = name.fileName;
 	} else {
 		fileName = directory.fileName;
-		if (fileName.size() && (fileName[fileName.size()-1] != pathSepChar))
+		if (!fileName.empty() && !fileName.ends_with(pathSepChar))
 			fileName += pathSepString;
 		fileName += name.fileName;
 	}
@@ -119,36 +118,36 @@ namespace {
 // Encapsulate Win32 CompareStringW
 [[nodiscard]] int Compare(const GUI::gui_string &a, const GUI::gui_string &b) noexcept {
 	return ::CompareStringW(LOCALE_SYSTEM_DEFAULT, NORM_IGNORECASE,
-		a.c_str(), static_cast<int>(a.length()),
-		b.c_str(), static_cast<int>(b.length()));
+		a.c_str(), -1,
+		b.c_str(), -1);
 }
 
 }
 
 #endif
 
-bool FilePath::operator==(const FilePath &other) const noexcept {
-	return SameNameAs(other);
-}
-
-bool FilePath::operator<(const FilePath &other) const noexcept {
+std::weak_ordering FilePath::operator<=>(const FilePath &other) const noexcept {
 #ifdef _WIN32
-	return CSTR_LESS_THAN == Compare(fileName, other.fileName);
+	switch (Compare(fileName, other.fileName)) {
+	case CSTR_EQUAL:
+		return std::weak_ordering::equivalent;
+	case CSTR_LESS_THAN:
+		return std::weak_ordering::less;
+	default:
+		return std::weak_ordering::greater;
+	}
 #else
-	return fileName < other.fileName;
+	return fileName <=> other.fileName;
 #endif
 }
 
 bool FilePath::SameNameAs(const FilePath &other) const noexcept {
-#ifdef _WIN32
-	return CSTR_EQUAL == Compare(fileName, other.fileName);
-#else
-	return fileName == other.fileName;
-#endif
+	const std::weak_ordering ordering = *this <=> other;
+	return (ordering == std::weak_ordering::equivalent);
 }
 
 bool FilePath::IsSet() const noexcept {
-	return fileName.length() > 0;
+	return !fileName.empty();
 }
 
 bool FilePath::IsUntitled() const noexcept {
@@ -157,13 +156,13 @@ bool FilePath::IsUntitled() const noexcept {
 }
 
 bool FilePath::IsAbsolute() const noexcept {
-	if (fileName.length() == 0)
+	if (fileName.empty())
 		return false;
 #if defined(__unix__) || defined(__APPLE__)
 	if (fileName[0] == '/')
 		return true;
 #endif
-#ifdef WIN32
+#ifdef _WIN32
 	if (fileName[0] == pathSepChar || fileName[1] == ':')	// UNC path or drive separator
 		return true;
 #endif
@@ -172,7 +171,7 @@ bool FilePath::IsAbsolute() const noexcept {
 }
 
 bool FilePath::IsRoot() const noexcept {
-#ifdef WIN32
+#ifdef _WIN32
 	if (fileName.length() >= 2 && (fileName[0] == pathSepChar) && (fileName[1] == pathSepChar)) {
 		// Starts with "\\" so could be UNC \\server or \\server\share
 		const size_t posSep = fileName.find(pathSepChar, 2);
@@ -188,8 +187,8 @@ bool FilePath::IsRoot() const noexcept {
 #endif
 }
 
-int FilePath::RootLength() noexcept {
-#ifdef WIN32
+size_t FilePath::RootLength() noexcept {
+#ifdef _WIN32
 	return 3;
 #else
 	return 1;
@@ -205,27 +204,23 @@ std::string FilePath::AsUTF8() const {
 }
 
 FilePath FilePath::Name() const {
-	const size_t dirEnd = fileName.rfind(pathSepChar);
-	if (dirEnd != GUI::gui_string::npos)
+	if (const size_t dirEnd = fileName.rfind(pathSepChar); dirEnd != GUI::gui_string::npos)
 		return fileName.substr(dirEnd + 1);
-	else
-		return fileName;
+	return fileName;
 }
 
 FilePath FilePath::BaseName() const {
-	const size_t dirEnd = fileName.rfind(pathSepChar);
 	const size_t extStart = fileName.rfind('.');
-	if (dirEnd != GUI::gui_string::npos) {
+	if (const size_t dirEnd = fileName.rfind(pathSepChar); dirEnd != GUI::gui_string::npos) {
 		if (extStart > dirEnd) {
-			return FilePath(fileName.substr(dirEnd + 1, extStart - dirEnd - 1));
-		} else {
-			return FilePath(fileName.substr(dirEnd + 1));
+			return { fileName.substr(dirEnd + 1, extStart - dirEnd - 1) };
 		}
-	} else if (extStart != GUI::gui_string::npos) {
-		return FilePath(fileName.substr(0, extStart));
-	} else {
-		return fileName;
+		return { fileName.substr(dirEnd + 1) };
 	}
+	if (extStart != GUI::gui_string::npos) {
+		return { fileName.substr(0, extStart) };
+	}
+	return fileName;
 }
 
 FilePath FilePath::Extension() const {
@@ -233,24 +228,20 @@ FilePath FilePath::Extension() const {
 	const size_t extStart = fileName.rfind('.');
 	if ((extStart != GUI::gui_string::npos) && ((dirEnd == GUI::gui_string::npos) || (extStart > dirEnd)))
 		return fileName.substr(extStart + 1);
-	else
-		return GUI_TEXT("");
+	return GUI_TEXT("");
 }
 
 FilePath FilePath::Directory() const {
 	if (IsRoot()) {
-		return FilePath(fileName);
-	} else {
-		size_t lenDirectory = fileName.rfind(pathSepChar);
-		if (lenDirectory != GUI::gui_string::npos) {
-			if (lenDirectory < static_cast<size_t>(RootLength())) {
-				lenDirectory = static_cast<size_t>(RootLength());
-			}
-			return FilePath(fileName.substr(0, lenDirectory));
-		} else {
-			return FilePath();
-		}
+		return { fileName };
 	}
+	if (size_t lenDirectory = fileName.rfind(pathSepChar); lenDirectory != GUI::gui_string::npos) {
+		if (lenDirectory < RootLength()) {
+			lenDirectory = RootLength();
+		}
+		return { fileName.substr(0, lenDirectory) };
+	}
+	return {};
 }
 
 namespace {
@@ -298,12 +289,12 @@ int stat(const wchar_t *path, FileStatus *buffer) noexcept {
 
 FilePath FilePath::NormalizePath() const {
 	if (fileName.empty()) {
-		return FilePath();
+		return {};
 	}
 	GUI::gui_string path(fileName);
-#ifdef WIN32
-	// Convert unix path separators to Windows
-	std::replace(path.begin(), path.end(), L'/', pathSepChar);
+#ifdef _WIN32
+	// Convert Unix path separators to Windows
+	std::ranges::replace(path, L'/', pathSepChar);
 #endif
 	GUI::gui_string_view source = path;
 	GUI::gui_string absPathString;
@@ -341,13 +332,13 @@ FilePath FilePath::NormalizePath() const {
 			break;
 		source.remove_prefix(separator+1);
 	}
-	return FilePath(absPathString);
+	return { absPathString };
 }
 
 GUI::gui_string FilePath::RelativePathTo(const FilePath &filePath) const {
-	// Only handles simple case where filePath is in this directory or a subdirectory
+	// Only handles simple case where filePath is in this directory or a sub-directory
 	GUI::gui_string relPath = filePath.fileName;
-	if (!fileName.empty() && StartsWith(relPath, fileName)) {
+	if (!fileName.empty() && relPath.starts_with(fileName)) {
 		relPath = relPath.substr(fileName.length());
 		if (!relPath.empty()) {
 			// Remove directory separator
@@ -362,13 +353,14 @@ GUI::gui_string FilePath::RelativePathTo(const FilePath &filePath) const {
  * If the path is absolute, return the same path.
  */
 FilePath FilePath::AbsolutePath() const {
-#ifdef WIN32
-	// The runtime libraries for GCC and Visual C++ give different results for _fullpath
+#ifdef _WIN32
+	// The run-time libraries for GCC and Visual C++ give different results for _fullpath
 	// so use the OS.
-	GUI::gui_char absPath[2000] {};
+	constexpr size_t maxAbsPath = 2000;
+	GUI::gui_char absPath[maxAbsPath] {};
 	GUI::gui_char *fileBit = nullptr;
-	::GetFullPathNameW(AsInternal(), sizeof(absPath)/sizeof(absPath[0]), absPath, &fileBit);
-	return FilePath(absPath);
+	::GetFullPathNameW(AsInternal(), std::size(absPath), absPath, &fileBit);
+	return { absPath };
 #else
 	if (IsAbsolute()) {
 		return NormalizePath();
@@ -380,7 +372,7 @@ FilePath FilePath::AbsolutePath() const {
 
 FilePath FilePath::GetWorkingDirectory() {
 	// Call getcwd with (nullptr, 0) to always allocate
-#ifdef WIN32
+#ifdef _WIN32
 	GUI::gui_char *pdir = _wgetcwd(nullptr, 0);
 #else
 	GUI::gui_char *pdir = getcwd(nullptr, 0);
@@ -397,9 +389,9 @@ FilePath FilePath::GetWorkingDirectory() {
 		if (!gswd.empty() && (gswd.back() == pathSepChar)) {
 			gswd.pop_back();
 		}
-		return FilePath(gswd);
+		return { gswd };
 	}
-	return FilePath();
+	return {};
 }
 
 bool FilePath::SetWorkingDirectory() const noexcept {
@@ -422,7 +414,7 @@ FilePath FilePath::UserHomeDirectory() {
 }
 
 void FilePath::List(FilePathSet &directories, FilePathSet &files) const {
-#ifdef WIN32
+#ifdef _WIN32
 	FilePath wildCard(*this, GUI_TEXT("*.*"));
 	WIN32_FIND_DATAW findFileData;
 	HANDLE hFind = ::FindFirstFileW(wildCard.AsInternal(), &findFileData);
@@ -466,30 +458,29 @@ void FilePath::List(FilePathSet &directories, FilePathSet &files) const {
 
 	closedir(dp);
 #endif
-	std::sort(files.begin(), files.end());
-	std::sort(directories.begin(), directories.end());
+	std::ranges::sort(files);
+	std::ranges::sort(directories);
 }
 
 FILE *FilePath::Open(const GUI::gui_char *mode) const noexcept {
 	if (IsSet()) {
 		return fopen(fileName.c_str(), mode);
-	} else {
-		return nullptr;
 	}
+	return nullptr;
 }
 
 std::string FilePath::Read() const {
 	/// Size of block for file reading.
-	constexpr size_t readBlockSize = 64 * 1024;
+	constexpr unsigned int readBlockSize = 64 * 1024;
 
 	std::string data;
 	FileHolder fp(Open(fileRead));
 	if (fp) {
 		std::string block(readBlockSize, '\0');
-		size_t lenBlock = fread(&block[0], 1, block.size(), fp.get());
+		size_t lenBlock = fread(block.data(), 1, block.size(), fp.get());
 		while (lenBlock > 0) {
 			data.append(block, 0, lenBlock);
-			lenBlock = fread(&block[0], 1, block.size(), fp.get());
+			lenBlock = fread(block.data(), 1, block.size(), fp.get());
 		}
 	}
 	return data;
@@ -512,18 +503,18 @@ time_t FilePath::ModifiedTime() const noexcept {
 	FileStatus statusFile;
 	if (stat(AsInternal(), &statusFile) != -1)
 		return statusFile.st_mtime;
-	else
-		return 0;
+	return 0;
 }
 
 long long FilePath::GetFileLength() const noexcept {
-#ifdef WIN32
+#ifdef _WIN32
 	// Using Win32 API as stat variants are complex and there were problems with stat
 	// working on XP when compiling with XP compatibility flag.
 	WIN32_FILE_ATTRIBUTE_DATA fad {};
 	if (!GetFileAttributesEx(AsInternal(), GetFileExInfoStandard, &fad))
 		return 0;
-	return (static_cast<unsigned long long>(fad.nFileSizeHigh) << 32) + fad.nFileSizeLow;
+	constexpr size_t bitsDWORD = 32;
+	return (static_cast<unsigned long long>(fad.nFileSizeHigh) << bitsDWORD) + fad.nFileSizeLow;
 #else
 	struct stat statusFile;
 	if (stat(AsInternal(), &statusFile) != -1)
@@ -543,7 +534,7 @@ bool FilePath::Exists() const noexcept {
 bool FilePath::IsDirectory() const noexcept {
 	FileStatus statusFile;
 	if (stat(AsInternal(), &statusFile) != -1)
-#ifdef WIN32
+#ifdef _WIN32
 		return (statusFile.st_mode & _S_IFDIR) != 0;
 #else
 		return (statusFile.st_mode & S_IFDIR) != 0;
@@ -558,9 +549,8 @@ namespace {
 void Lowercase(GUI::gui_string &s) {
 	const int sLength = static_cast<int>(s.length());
 	const int chars = ::LCMapString(LOCALE_SYSTEM_DEFAULT, LCMAP_LOWERCASE, s.c_str(), sLength, nullptr, 0);
-	GUI::gui_string vc(chars, 0);
-	::LCMapString(LOCALE_SYSTEM_DEFAULT, LCMAP_LOWERCASE, s.c_str(), sLength, vc.data(), chars);
-	s = vc;
+	s.resize(chars);
+	::LCMapString(LOCALE_SYSTEM_DEFAULT, LCMAP_LOWERCASE, s.c_str(), sLength, s.data(), chars);
 }
 #endif
 
@@ -618,11 +608,11 @@ bool FilePath::Matches(GUI::gui_string_view pattern) const {
 	return false;
 }
 
-#ifdef WIN32
+#ifdef _WIN32
 
 namespace {
 
-typedef DWORD(STDAPICALLTYPE *GetLongSig)(const GUI::gui_char *lpszShortPath, GUI::gui_char *lpszLongPath, DWORD cchBuffer);
+using GetLongSig = DWORD(STDAPICALLTYPE *)(const GUI::gui_char *lpszShortPath, GUI::gui_char *lpszLongPath, DWORD cchBuffer);
 GetLongSig pfnGetLong = nullptr;
 bool kernelTried = false;
 
@@ -655,13 +645,13 @@ bool MakeLongPath(const GUI::gui_char *shortPath, GUI::gui_string &longPath) {
 	}
 	GUI::gui_string gsLong(1, L'\0');
 	// Call with too-short string returns size + terminating NUL
-	const DWORD size = (pfnGetLong)(shortPath, &gsLong[0], 0);
+	const DWORD size = (pfnGetLong)(shortPath, gsLong.data(), 0);
 	if (size == 0) {
 		return false;
 	}
 	gsLong.resize(size);
 	// Call with correct size string returns size without terminating NUL
-	const DWORD characters = (pfnGetLong)(shortPath, &gsLong[0], size);
+	const DWORD characters = (pfnGetLong)(shortPath, gsLong.data(), size);
 	if (characters != 0) {
 		longPath.assign(gsLong, 0, characters);
 	}
@@ -673,7 +663,7 @@ bool MakeLongPath(const GUI::gui_char *shortPath, GUI::gui_string &longPath) {
 #endif
 
 void FilePath::FixName() {
-#ifdef WIN32
+#ifdef _WIN32
 	// Only used on Windows to use long file names and fix the case of file names
 	GUI::gui_string longPath;
 	// first try MakeLongPath which corrects the path and the case of filename too
@@ -682,7 +672,7 @@ void FilePath::FixName() {
 	} else {
 		// On Windows file comparison is done case insensitively so the user can
 		// enter scite.cxx and still open this file, SciTE.cxx. To ensure that the file
-		// is saved with correct capitalisation FindFirstFile is used to find out the
+		// is saved with correct capitalization FindFirstFile is used to find out the
 		// real name of the file.
 		WIN32_FIND_DATAW FindFileData;
 		HANDLE hFind = ::FindFirstFileW(AsInternal(), &FindFileData);
@@ -755,11 +745,13 @@ std::string CommandExecute(const GUI::gui_char *command, const GUI::gui_char *di
 
 	if (running && pi.hProcess && pi.hThread) {
 		// Wait until child process exits but time out after 5 seconds.
-		::WaitForSingleObject(pi.hProcess, 5 * 1000);
+		constexpr DWORD maxWait = 5 * 1000;
+		::WaitForSingleObject(pi.hProcess, maxWait);
 
 		DWORD bytesRead = 0;
 		DWORD bytesAvail = 0;
-		char buffer[8 * 1024] {};
+		constexpr unsigned int pipeBufferSize = 8 * 1024;
+		char buffer[pipeBufferSize] {};
 
 		if (::PeekNamedPipe(hPipeRead, buffer, sizeof(buffer), &bytesRead, &bytesAvail, nullptr)) {
 			if (bytesAvail > 0) {
